package cc.fascinated.controller;

import cc.fascinated.model.auth.LoginRequest;
import cc.fascinated.model.auth.AuthToken;
import cc.fascinated.services.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @author Fascinated (fascinated7)
 */
@RestController
@RequestMapping(value = "/auth", produces = MediaType.APPLICATION_JSON_VALUE)
public class AuthenticationController {
    /**
     * The user service to use
     */
    private final UserService userService;

    @Autowired
    public AuthenticationController(UserService userService) {
        this.userService = userService;
    }

    /**
     * A POST request to get an auth token from a steam ticket.
     */
    @ResponseBody
    @PostMapping(value = "/login", consumes = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<?> getAuthToken(@RequestBody LoginRequest request) {
        if (request == null || request.getTicket() == null) {
            return ResponseEntity.badRequest().body(Map.of(
                    "error", "Invalid request or missing ticket"
            ));
        }
        AuthToken authToken = this.userService.getAuthToken(request.getTicket());
        return ResponseEntity.ok()
                .header("Authorization", authToken.getAuthToken())
                .build();
    }

    /**
     * A POST request to validate an auth token.
     */
    @ResponseBody
    @PostMapping(value = "/validate")
    public ResponseEntity<?> validateAuthToken(@RequestHeader("Authorization") String authToken) {
        String token = authToken == null ? null : authToken.replace("Bearer ", "");
        if (token == null) {
            return ResponseEntity.badRequest().body(Map.of(
                    "error", "Invalid request or missing token"
            ));
        }
        return new ResponseEntity<>(this.userService.isValidAuthToken(token) ? HttpStatus.OK : HttpStatus.UNAUTHORIZED);
    }
}


