package cc.fascinated.services;

import cc.fascinated.common.Request;
import cc.fascinated.model.token.steam.SteamAuthenticateUserTicketToken;
import kong.unirest.core.HttpResponse;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

/**
 * @author Fascinated (fascinated7)
 */
@Service
@Log4j2
public class SteamService {
    /**
     * Steam API endpoints.
     */
    private static final String STEAM_API_URL = "https://api.steampowered.com/";
    private static final String USER_AUTH_TICKET = STEAM_API_URL + "ISteamUserAuth/AuthenticateUserTicket/v1/?key=%s&appid=620980&ticket=%s";

    /**
     * The key to use for authentication
     * with the Steam API.
     */
    private final String steamKey;

    @Autowired
    public SteamService(@Value("${scoretracker.steam.api-key}") String steamKey) {
        this.steamKey = steamKey;
    }

    /**
     * Gets the steam ID from a user's ticket.
     *
     * @param ticket the ticket to get the steam ID from
     * @return the steam ID from the ticket
     */
    public SteamAuthenticateUserTicketToken getSteamUserFromTicket(String ticket) {
        HttpResponse<SteamAuthenticateUserTicketToken> response = Request.get(
                USER_AUTH_TICKET.formatted(steamKey, ticket),
                SteamAuthenticateUserTicketToken.class
        );
        if (response.getStatus() != 200) {
            log.error("Failed to get steam ID from ticket: %s".formatted(response.getStatus()));
            return null;
        }
        return response.getBody();
    }
}
